==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/dbPCellHeader.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_dbPCellHeader
#define HDR_dbPCellHeader

#include "dbLayout.h"
#include "dbPCellDeclaration.h"
#include "tlVariant.h"

#include <string.h>

namespace db
{

class PCellVariant;

struct PCellParametersCompareFunc
{
  bool operator() (const pcell_parameters_type *a, const pcell_parameters_type *b);
};

/**
 *  @brief A PCell header
 *
 *  The PCell header manages the PCell variants along with the PCell declaration.
 */
class PCellHeader
{
public:
  typedef std::map<const pcell_parameters_type *, db::PCellVariant *, PCellParametersCompareFunc> variant_map_t;

  /**
   *  @brief The default constructor
   */
  PCellHeader(size_t pcell_id, const std::string &name, PCellDeclaration *declaration);

  /**
   *  @brief The destructor
   */
  ~PCellHeader ();

  /**
   *  @brief Copy constructor
   */
  PCellHeader (const PCellHeader &d);

  /**
   *  @brief Get the name
   */
  const std::string &get_name () const
  {
    return m_name;
  }

  /**
   *  @brief Get the declaration
   */
  const PCellDeclaration *declaration () const
  {
    return mp_declaration;
  }

  /**
   *  @brief Set the declaration
   *
   *  The declaration can be 0, in which case the PCell cannot produce any code.
   */
  void declaration (PCellDeclaration *declaration);

  /**
   *  @brief Get the layer index list for this PCell declaration
   */
  std::vector<unsigned int> get_layer_indices (db::Layout &layout);

  /**
   *  @brief Get the variant for a given parameter set if it already exists.
   *
   *  If no variant is registered for this parameter set, 0 is returned.
   */
  PCellVariant *get_variant (db::Layout &layout, const pcell_parameters_type &parameters);

  /**
   *  @brief Register a variant 
   */
  void unregister_variant (PCellVariant *variant);

  /**
   *  @brief Unregister a variant 
   */
  void register_variant (PCellVariant *variant);

  /**
   *  @brief Get the PCell Id for this variant
   */
  size_t pcell_id () const
  {
    return m_pcell_id;
  }

private:
  std::vector<unsigned int> m_layer_indices;
  std::vector<db::PCellLayerDeclaration> m_layer_declarations;
  variant_map_t m_variant_map;
  db::PCellDeclaration *mp_declaration;
  size_t m_pcell_id;
  std::string m_name;
};
  
}

#endif

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/dbPCellHeader.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_dbPCellHeader
#define HDR_dbPCellHeader

#include "config.h"

#include "dbLayout.h"
#include "dbPCellDeclaration.h"
#include "tlVariant.h"

#include <string.h>

namespace db
{

class PCellVariant;

struct KLAYOUT_DLL PCellParametersCompareFunc
{
  bool operator() (const pcell_parameters_type *a, const pcell_parameters_type *b) const;
};

/**
 *  @brief A PCell header
 *
 *  The PCell header manages the PCell variants along with the PCell declaration.
 */
class KLAYOUT_DLL PCellHeader
{
public:
  typedef std::map<const pcell_parameters_type *, db::PCellVariant *, PCellParametersCompareFunc> variant_map_t;

  /**
   *  @brief The default constructor
   */
  PCellHeader(size_t pcell_id, const std::string &name, PCellDeclaration *declaration);

  /**
   *  @brief The destructor
   */
  ~PCellHeader ();

  /**
   *  @brief Copy constructor
   */
  PCellHeader (const PCellHeader &d);

  /**
   *  @brief Get the name
   */
  const std::string &get_name () const
  {
    return m_name;
  }

  /**
   *  @brief Get the declaration
   */
  const PCellDeclaration *declaration () const
  {
    return mp_declaration;
  }

  /**
   *  @brief Set the declaration
   *
   *  The declaration can be 0, in which case the PCell cannot produce any code.
   */
  void declaration (PCellDeclaration *declaration);

  /**
   *  @brief Get the layer index list for this PCell declaration
   */
  std::vector<unsigned int> get_layer_indices (db::Layout &layout);

  /**
   *  @brief Get the variant for a given parameter set if it already exists.
   *
   *  If no variant is registered for this parameter set, 0 is returned.
   */
  PCellVariant *get_variant (db::Layout &layout, const pcell_parameters_type &parameters);

  /**
   *  @brief Register a variant 
   */
  void unregister_variant (PCellVariant *variant);

  /**
   *  @brief Unregister a variant 
   */
  void register_variant (PCellVariant *variant);

  /**
   *  @brief Get the PCell Id for this variant
   */
  size_t pcell_id () const
  {
    return m_pcell_id;
  }

private:
  std::vector<unsigned int> m_layer_indices;
  std::vector<db::PCellLayerDeclaration> m_layer_declarations;
  variant_map_t m_variant_map;
  db::PCellDeclaration *mp_declaration;
  size_t m_pcell_id;
  std::string m_name;
};
  
}

#endif
